@@ -17,8 +17,7 @@ class MPOSE():
                  config_file=None,
                  velocities=False,
                  remove_zip=False,
-                 overwrite=False,
-                 verbose=True
+                 overwrite=False
                  ):
         
         """
@@ -41,8 +40,7 @@ class MPOSE():
         self.velocities = velocities
         self.remove_zip = remove_zip
         self.overwrite = overwrite
-        self.verbose = verbose
-        
+                
         self.get_config()
         
         self.T = self.config['DATASET']['T']
@@ -50,8 +48,7 @@ class MPOSE():
         self.K = self.config['DATASET'][pose_extractor]['K']
         self.center_1 = self.config['DATASET'][pose_extractor]['center_1']
         self.center_2 = self.config['DATASET'][pose_extractor]['center_2']
-        self.module_keypoint_1 = self.config['DATASET'][pose_extractor]['module_keypoint_1']
-        self.module_keypoint_2 = self.config['DATASET'][pose_extractor]['module_keypoint_2']
+        self.module_keypoint = self.config['DATASET'][pose_extractor]['module_keypoint']
         self.h = self.config['DATASET'][self.pose_extractor]['head']
         self.rf = self.config['DATASET'][self.pose_extractor]['right_foot']
         self.lf = self.config['DATASET'][self.pose_extractor]['left_foot']
@@ -75,8 +72,7 @@ class MPOSE():
             
     # Configuration         
     def get_config(self):
-        if self.verbose:
-            print(f"Initializing MPOSE2021 with {self.pose_extractor} Pose Extractor")
+        print(f"Initializing MPOSE2021 with {self.pose_extractor} Pose Extractor")
         if self.config_file is None:
             with pkg_resources.path(mpose, 'config.yaml') as config:
                 self.config_file = config
@@ -85,23 +81,17 @@ class MPOSE():
 
     # Get Data
     def download_data(self):
-        if self.verbose:
-            print(f"Downloading Data...")
+        print(f"Downloading Data...")
         if not os.path.exists(self.config['CACHE_DIR']):
             os.makedirs(self.config['CACHE_DIR'])
         download_file(self.config['URLS'][self.pose_extractor], self.config['CACHE_DIR']+self.pose_extractor+'.zip',
-                      overwrite=self.overwrite, verbose=self.verbose)
-        if self.verbose:
-            print(f"Extracting Data...")
+                      overwrite=self.overwrite)
+        
+        print(f"Extracting Archive to {self.config['CACHE_DIR']}...")
         if not os.path.exists(self.config['CACHE_DIR']+self.pose_extractor+'/'+self.split+'/'):
-            if self.verbose:
-                print(f"Extracting Archive to {self.config['CACHE_DIR']}...")
             unzip(self.config['CACHE_DIR']+self.pose_extractor+'.zip', self.config['CACHE_DIR'])
-        elif self.verbose:
-            print(f"File exists in {self.config['CACHE_DIR']+self.pose_extractor+'/'}. specify overwrite=True if intended")
         if self.remove_zip:
-            if self.verbose:
-                print(f"Removing Archive...")
+            print(f"Removing Archive...")
             os.remove(self.config['CACHE_DIR']+self.pose_extractor+'.zip')
         
     def load_data(self):
@@ -131,9 +121,11 @@ class MPOSE():
         
     # Transforms
     def apply_transforms(self):
-        if self.velocities:
+        if 'legacy' in self.pose_extractor:
+            pass
+        elif self.velocities:
             self.add_velocities() 
-        if self.preprocess == 'scale_and_center':
+        elif self.preprocess == 'scale_and_center':
             self.scale_and_center()
         elif self.preprocess == 'scale_to_unit':
             self.scale_to_unit()   
@@ -158,30 +150,23 @@ class MPOSE():
             print('Poses already scaled. Please call reduce_keypoints() only before scale_and_center()!')
             return
         seq_list = []
-        to_prune = []
-        
-        for group in [self.h, self.rf, self.lf]:
-            if len(group) > 1:
-                to_prune.append(group[1:])
-        to_prune = [item for sublist in to_prune for item in sublist]
-        
         for seq in self.X_train:
             seq[:,self.h[0],:] = np.true_divide(seq[:,self.h,:].sum(1), (seq[:,self.h,:] != 0).sum(1)+1e-9)
             seq[:,self.rf[0],:] = np.true_divide(seq[:,self.rf,:].sum(1), (seq[:,self.rf,:] != 0).sum(1)+1e-9)
             seq[:,self.lf[0],:] = np.true_divide(seq[:,self.lf,:].sum(1), (seq[:,self.lf,:] != 0).sum(1)+1e-9)
-            seq_list.append(seq)
+
+            seq_list.append(seq[:, :self.config['DATASET'][self.pose_extractor]['k'], :])           
         self.X_train = np.stack(seq_list)
-        self.X_train = np.delete(self.X_train, to_prune, 2)
-        
+
         seq_list = []
         for seq in self.X_test:
             seq[:,self.h[0],:] = np.true_divide(seq[:,self.h,:].sum(1), (seq[:,self.h,:] != 0).sum(1)+1e-9)
             seq[:,self.rf[0],:] = np.true_divide(seq[:,self.rf,:].sum(1), (seq[:,self.rf,:] != 0).sum(1)+1e-9)
             seq[:,self.lf[0],:] = np.true_divide(seq[:,self.lf,:].sum(1), (seq[:,self.lf,:] != 0).sum(1)+1e-9)
-            seq_list.append(seq)           
+
+            seq_list.append(seq[:, :self.config['DATASET'][self.pose_extractor]['k'], :])           
         self.X_test = np.stack(seq_list)
-        self.X_test = np.delete(self.X_test, to_prune, 2)
-        
+            
     def scale_and_center(self):
         if self.scaled:
             print('Poses already scaled!')
@@ -193,8 +178,7 @@ class MPOSE():
                 pose_list = []
                 for pose in seq:
                     zero_point = (pose[self.center_1, :2] + pose[self.center_2,:2]) / 2
-                    module_keypoint = (pose[self.module_keypoint_1, :2] + pose[self.module_keypoint_2,:2]) / 2
-                    scale_mag = np.linalg.norm(zero_point - module_keypoint)
+                    scale_mag = np.linalg.norm(zero_point - pose[self.module_keypoint,:2])
                     if scale_mag < 1:
                         scale_mag = 1
                     pose[:,:2] = (pose[:,:2] - zero_point) / scale_mag
@@ -272,20 +256,11 @@ class MPOSE():
         self.X_train = self.X_train[...,:-1]
         self.X_test = self.X_test[...,:-1]
             
-    def flatten_features(self):
-        self.X_train = self.X_train.reshape(self.X_train.shape[0], self.T, -1)
-        self.X_test = self.X_test.reshape(self.X_test.shape[0], self.T, -1)
-    
-    def reduce_labels(self):
-        for i in range(len(self.y_train)):
-            self.y_train[i] = self.config['DATASET']['red_lab'][str(self.y_train[i])]
-        for i in range(len(self.y_test)):
-            self.y_test[i] = self.config['DATASET']['red_lab'][str(self.y_test[i])]
-    
     def reset_data(self):
         if self.remove_zip is True:
             print('Error! The zip file was removed from disk!')
             return
+        
         self.load_data()
         
         
